==> netpanzer_0.1.5.orig.tar.gz: netpanzer-0.1.5/src/NetPanzer/Particles/TrajectoryParticle2D.hpp <==
/*
Copyright (C) 1998 Pyrosoft Inc. (www.pyrosoftgames.com), Matthew Bogue
 
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __TrajectoryParticle2D_hpp__
#define __TrajectoryParticle2D_hpp__


#include "Particle2D.hpp"


//--------------------------------------------------------------------------
class TrajectoryParticle2D : public Particle2D
{
protected:
    fXYZ  initialPos;
    int   initialVelocity; // The initial initialVelocity of the particle.
    float trajectoryAngle; // Needs to be in radians.
    fXYZ  direction;
    int   dieAtMidFlight;
    float halfLife;

public:
    TrajectoryParticle2D(	const fXYZ &pos,
                          int         maxSpeed,
                          float       trajectoryAngle,
                          int         dieAtMidFlight = 0);

    virtual void sim();
    virtual void draw(const Surface &dest, SpriteSorter &sorter)
    {}

}
; // end TrajectoryParticle2D

#endif // __TrajectoryParticle2D_hpp__

==> netpanzer_0.8.2.orig.tar.gz: netpanzer-0.8.2/src/NetPanzer/Particles/TrajectoryParticle2D.hpp <==
/*
Copyright (C) 1998 Pyrosoft Inc. (www.pyrosoftgames.com), Matthew Bogue
 
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __TrajectoryParticle2D_hpp__
#define __TrajectoryParticle2D_hpp__


#include "Particle2D.hpp"


//--------------------------------------------------------------------------
class TrajectoryParticle2D : public Particle2D
{
protected:
    fXYZ  initialPos;
    int   initialVelocity; // The initial initialVelocity of the particle.
    float trajectoryAngle; // Needs to be in radians.
    fXYZ  direction;
    int   dieAtMidFlight;
    float halfLife;

public:
    TrajectoryParticle2D(	const fXYZ &pos,
                          int         maxSpeed,
                          float       trajectoryAngle,
                          int         dieAtMidFlight = 0);

    virtual void sim();
    virtual void draw(const Surface&, SpriteSorter&)
    {}

}
; // end TrajectoryParticle2D

#endif // __TrajectoryParticle2D_hpp__
